@@ -28,6 +28,8 @@
 #' @export
 LearnerSurvGBM = R6Class("LearnerSurvGBM", inherit = LearnerSurv,
   public = list(
+    #' @description
+    #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
       ps = ParamSet$new(
         params = list(
@@ -56,7 +58,23 @@ LearnerSurvGBM = R6Class("LearnerSurvGBM", inherit = LearnerSurv,
       )
     },
 
-    train_internal = function(task) {
+    #' @description
+    #' The importance scores are extracted from the model slot `variable.importance`.
+    #' @return Named `numeric()`.
+    importance = function() {
+      if (is.null(self$model)) {
+        stopf("No model stored")
+      }
+      sum = summary(self$model, plotit = FALSE)
+      relinf = sum$rel.inf
+      names(relinf) = sum$var
+
+      relinf
+    }
+  ),
+
+  private = list(
+    .train = function(task) {
 
       # hacky formula construction as gbm fails when "type" argument specified in Surv()
       tn = task$target_names
@@ -75,7 +93,7 @@ LearnerSurvGBM = R6Class("LearnerSurvGBM", inherit = LearnerSurv,
       )
     },
 
-    predict_internal = function(task) {
+    .predict = function(task) {
 
       pv = self$param_set$get_values(tags = "predict")
       newdata = task$data()
@@ -97,17 +115,6 @@ LearnerSurvGBM = R6Class("LearnerSurvGBM", inherit = LearnerSurv,
 
       PredictionSurv$new(task = task, crank = lp, lp = lp)
 
-    },
-
-    importance = function() {
-      if (is.null(self$model)) {
-        stopf("No model stored")
-      }
-      sum = summary(self$model, plotit = FALSE)
-      relinf = sum$rel.inf
-      names(relinf) = sum$var
-
-      relinf
     }
   )
 )
