@@ -29,6 +29,8 @@
 #' learner$model@unpenalized
 LearnerSurvPenalized = R6Class("LearnerSurvPenalized", inherit = LearnerSurv,
   public = list(
+    #' @description
+    #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
       super$initialize(
         id = "surv.penalized",
@@ -55,7 +57,20 @@ LearnerSurvPenalized = R6Class("LearnerSurvPenalized", inherit = LearnerSurv,
         )
       },
 
-    train_internal = function(task) {
+    #' @description
+    #' The importance scores are extracted from the model slot `variable.importance`.
+    #' @return Named `numeric()`.
+    importance = function() {
+      if (is.null(self$model))
+        stopf("No model stored")
+
+      # importance defined by decreasing fitted weights
+      sort(self$model@weights, decreasing = TRUE)
+      }
+  ),
+
+  private = list(
+    .train = function(task) {
 
       # Checks missing data early to prevent crashing
       if(any(task$missings() > 0))
@@ -73,10 +88,10 @@ LearnerSurvPenalized = R6Class("LearnerSurvPenalized", inherit = LearnerSurv,
       }
 
       suppressWarnings(suppressMessages((invoke(penalized::penalized, response = task$truth(), penalized = penalized,
-             data = task$data(cols = task$feature_names), model = "cox", .args = pars))))
-      },
+                                                data = task$data(cols = task$feature_names), model = "cox", .args = pars))))
+    },
 
-    predict_internal = function(task) {
+    .predict = function(task) {
       # Again the penalized and unpenalized covariates are automatically converted to the
       # correct formula
       pars = self$param_set$get_values(tags = "predict")
@@ -101,14 +116,6 @@ LearnerSurvPenalized = R6Class("LearnerSurvPenalized", inherit = LearnerSurv,
       crank = as.numeric(sapply(x, function(y) sum(y[,1] * c(y[,2][1], diff(y[,2])))))
 
       PredictionSurv$new(task = task, distr = distr, crank = crank)
-      },
-
-    importance = function() {
-      if (is.null(self$model))
-        stopf("No model stored")
-
-      # importance defined by decreasing fitted weights
-      sort(self$model@weights, decreasing = TRUE)
-      }
-    )
+    }
+  )
 )
