@@ -22,8 +22,9 @@
 #' @export
 LearnerSurvSVM = R6Class("LearnerSurvSVM", inherit = LearnerSurv,
   public = list(
+    #' @description
+    #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
-
       ps = ParamSet$new(
         params = list(
           ParamFct$new(id = "type", default = "regression", levels = c("regression", "vanbelle1", "vanbelle2", "hybrid"), tags = "train"),
@@ -53,15 +54,18 @@ LearnerSurvSVM = R6Class("LearnerSurvSVM", inherit = LearnerSurv,
         predict_types = c("crank"),
         packages = c("survivalsvm")
         )
-      },
-    train_internal = function(task) {
+      }
+  ),
+
+  private = list(
+    .train = function(task) {
       invoke(survivalsvm::survivalsvm,
              formula = task$formula(),
              data = task$data(),
              .args = self$param_set$get_values(tags = "train"))
-      },
+    },
 
-    predict_internal = function(task) {
+    .predict = function(task) {
       # only a continuous ranking is returned
       fit = predict(self$model, newdata = task$data(cols = task$feature_names))
       PredictionSurv$new(task = task, crank = as.numeric(fit$predicted))
